#!/usr/bin/env python
#encoding: utf-8
#
#       AWN Test Python Applet
#
#       Copyright (c) 2008 IPoemI <ipoemi@gmail.com>
#
#       This library is free software; you can redistribute it and/or
#       modify it under the terms of the GNU Lesser General Public
#       License as published by the Free Software Foundation; either
#       version 2 of the License, or (at your option) any later version.
#
#       This library is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#       Lesser General Public License for more details.
#
#       You should have received a copy of the GNU Lesser General Public
#       License along with this library; if not, write to the
#       Free Software Foundation, Inc., 59 Temple Place - Suite 330,
#       Boston, MA 02111-1307, USA.

from awn.extras import AWNLib
from getdic import *
from textgrabber import *
import gtk, gobject

class NaverDicApplet(object):
    # pixel unit
    TEXT_AREA_INDENT = 10
    NUMBER_OF_RESULT = 10
    CONTENTS_WIDTH = 300
    CONTENTS_HEIGHT = 300

    def __init__(self):
        applet = AWNLib.initiate(
        {"name": "Naver Dictionary Applet", "short": "naverdic"})
        # draw widgets and make widget tree
        applet.title.set("Naver Dictionary")
        applet.icon.file("naverdic.png")
        dialog = applet.dialog.new("main")
        mainBox = gtk.VBox()
        mainBox.set_size_request(
        NaverDicApplet.CONTENTS_WIDTH, NaverDicApplet.CONTENTS_HEIGHT)
        titleLabel = gtk.Label()
        titleLabel.set_use_markup(True)
        titleLabel.set_markup("<b>Naver Dictionary</b>")
        mainBox.pack_start(titleLabel, False)
        mainBox.pack_start(gtk.HSeparator(), False, True, 5)
        searchBox = gtk.HBox()
        searchEntry = gtk.Entry()
        searchBox.add(searchEntry)
        searchButton = gtk.Button()
        searchButton.set_label("Search")
        searchBox.add(searchButton)
        mainBox.pack_start(searchBox, False)
        resultNotebook = gtk.Notebook()
        resultNotebook.set_tab_pos(gtk.POS_BOTTOM)
        resultNotebook.set_scrollable(True)
        mainBox.add(resultNotebook)
        mainBox.pack_start(gtk.HSeparator(), False, True, 5)
        sponsorLink = gtk.LinkButton("http://www.naver.com/")
        mainBox.pack_end(sponsorLink, False)
        dialog.add(mainBox)
        # set timer and handler connect
        gobject.timeout_add(1500, self.onTimer)
        # signal handler connect
        searchEntry.connect("key-press-event", self.onEnterKeyPressed)
        searchButton.connect("clicked", self.onSearchButtonClicked)
        # get clipboard
        self.clipboard = gtk.clipboard_get(gtk.gdk.SELECTION_CLIPBOARD)
        # necessary widget store in self instance
        self.resultNotebook = resultNotebook
        self.searchEntry = searchEntry
        self.dialog = dialog
        self.applet = applet
        # etc valuable
        self.lastClipboardText = ""

    def onTimer(self):
        self.clipboard.request_text(self.treatClipboardText)
        return True

    def treatClipboardText(self, clipboard, text, data):
        if not text:
            return
        text.strip()
        if self.lastClipboardText != text:
            self.lastClipboardText = text
            self.searchEntry.set_text(text)
            self.onSearchButtonClicked()


    def onEnterKeyPressed(self, widget, event, *args):
        if event.keyval == 65293:
            self.onSearchButtonClicked(self)

    def onSearchButtonClicked(self, *args):
        notebook = self.resultNotebook
        word = self.searchEntry.get_text()
        words = notebook.get_children()
        pageNum = 0
        for child in words:
            label = notebook.get_tab_label(child)
            if label.get_label() == word:
                notebook.set_current_page(pageNum)
                return
            pageNum += 1
        else:
            result = getDic(word)
            textgrabber = TextGrabber()
            textgrabber.feed(result)
            textgrabber.close()
            self.insertResult(word, textgrabber.getResult())
            pass

    def insertResult(self, word, contents):
        notebook = self.resultNotebook
        txtBuffer = gtk.TextBuffer()
        txtBuffer.set_text(contents)
        txtView = gtk.TextView(txtBuffer)
        txtView.set_editable(False)
        txtView.set_indent(NaverDicApplet.TEXT_AREA_INDENT)
        #txtView.set_wrap_mode(gtk.WRAP_WORD)
        scrolledWindow = gtk.ScrolledWindow()
        scrolledWindow.set_policy(
        gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
        scrolledWindow.add(txtView)
        label = gtk.Label()
        label.set_label(word)
        txtView.show()
        label.show()
        scrolledWindow.show()
        if notebook.get_n_pages() == NaverDicApplet.NUMBER_OF_RESULT:
            tmp = notebook.get_nth_page(NaverDicApplet.NUMBER_OF_RESULT - 1)
            notebook.remove_page(NaverDicApplet.NUMBER_OF_RESULT - 1)
            tmp.destroy()
        notebook.insert_page(scrolledWindow, label, 0)
        notebook.set_current_page(0)

    def run(self):
        AWNLib.start(self.applet)

if __name__ == "__main__":
    naverdic = NaverDicApplet()
    naverdic.run()
